' ========================================================================================
' GdipGetImageBounds
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

' ========================================================================================
' The following example creates an Image object based on a metafile and then draws the
' image. Next, the code calls the GdipGetBounds function to get the bounding rectangle for
' the image. The code makes two attempts to display 75 percent of the image. The first
' attempt fails because it specifies (0, 0) for the upper-left corner of the source
' rectangle. The second attempt succeeds because it uses the X and Y data members returned
' by GdipGetBounds to specify the upper-left corner of the source rectangle.
' ========================================================================================
SUB GDIP_GetImageBounds (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pImage AS DWORD
   LOCAL strFileName AS STRING
   LOCAL boundsRect AS RECTF
   LOCAL unit AS LONG

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create an Image object, and then clone it.
   strFileName = UCODE$("climber.emf")
   hStatus = GdipLoadImageFromFile(STRPTR(strFileName), pImage)

   ' // Draw the image.
   hStatus = GdipDrawImage(pGraphics, pImage, 0, 0)

   ' // Get the bounding rectangle for the image (metafile).
   hStatus = GdipGetImageBounds(pImage, boundsRect, unit)

   ' // Attempt to draw 75 percent of the image.
   ' // Less than 75 percent of the image will be visible because the
   ' // upper-left corner of the image's bounding rectangle is not (0, 0).
   hStatus = GdipDrawImagePointRect(pGraphics, pImage, 250, 0, 100, 50, 0.75 * boundsRect.Width, boundsRect.Height, %UnitPixel)

   ' // Draw 75 percent of the image.
   hStatus = GdipDrawImagePointRect(pGraphics, pImage, 250, 80, boundsRect.x, boundsRect.y, 0.75 * boundsRect.Width, boundsRect.Height, %UnitPixel)

   ' // Cleanup
   IF pImage THEN GdipDisposeImage(pImage)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   DIALOG NEW 0, "GdipGetImageBounds", , , 290, 170, %WS_OVERLAPPED OR %WS_THICKFRAME OR %WS_SYSMENU OR _
   %WS_MINIMIZEBOX OR %WS_MAXIMIZEBOX OR %WS_VISIBLE OR %DS_CENTER TO hDlg
   DIALOG SET COLOR hDlg, %BLACK, %WHITE
   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   LOCAL hDC AS DWORD
   LOCAL ps AS PAINTSTRUCT

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

      CASE %WM_PAINT
         hDC = BeginPaint(CBHNDL, ps)
         GDIP_GetImageBounds hDC
         EndPaint(CBHNDL, ps)

   END SELECT

END FUNCTION
' ========================================================================================
