' ========================================================================================
' GdipGetImageBounds
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

%IDC_GRAPHIC  = 101

' ========================================================================================
' The following example creates an Image object based on a metafile and then draws the
' image. Next, the code calls the GdipGetBounds function to get the bounding rectangle for
' the image. The code makes two attempts to display 75 percent of the image. The first
' attempt fails because it specifies (0, 0) for the upper-left corner of the source
' rectangle. The second attempt succeeds because it uses the X and Y data members returned
' by GdipGetBounds to specify the upper-left corner of the source rectangle.
' ========================================================================================
SUB GDIP_GetImageBounds (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pImage AS DWORD
   LOCAL strFileName AS STRING
   LOCAL boundsRect AS RECTF
   LOCAL unit AS LONG

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create an Image object, and then clone it.
   strFileName = UCODE$("climber.emf")
   hStatus = GdipLoadImageFromFile(STRPTR(strFileName), pImage)

   ' // Draw the image.
   hStatus = GdipDrawImage(pGraphics, pImage, 0, 0)

   ' // Get the bounding rectangle for the image (metafile).
   hStatus = GdipGetImageBounds(pImage, boundsRect, unit)

   ' // Attempt to draw 75 percent of the image.
   ' // Less than 75 percent of the image will be visible because the
   ' // upper-left corner of the image's bounding rectangle is not (0, 0).
   hStatus = GdipDrawImagePointRect(pGraphics, pImage, 250, 0, 100, 50, 0.75 * boundsRect.Width, boundsRect.Height, %UnitPixel)

   ' // Draw 75 percent of the image.
   hStatus = GdipDrawImagePointRect(pGraphics, pImage, 250, 80, boundsRect.x, boundsRect.y, 0.75 * boundsRect.Width, boundsRect.Height, %UnitPixel)

   ' // Cleanup
   IF pImage THEN GdipDisposeImage(pImage)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL hdc AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   ' Create a new dialog
   DIALOG NEW PIXELS, 0, "GdipGetImageBounds", , , 430, 250, %WS_SYSMENU TO hDlg

   ' Add a graphic control
   CONTROL ADD GRAPHIC, hDlg, %IDC_GRAPHIC,"", 0, 0, 430, 250
   ' Select the drawing target
   GRAPHIC ATTACH hDlg, %IDC_GRAPHIC
   ' Set the foreground and background color
   GRAPHIC COLOR %BLACK, %WHITE
   ' Clear the entire selected graphic window
   GRAPHIC CLEAR
   ' Retrieve the handle of the device context
   GRAPHIC GET DC TO hdc
   ' Draw the graphics
   GDIP_GetImageBounds hdc

   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

   END SELECT

END FUNCTION
' ========================================================================================
